@@ -2,9 +2,9 @@ use strict;
 use warnings;
 package Dist::Zilla::Plugin::Test::NewVersion;
 {
-  $Dist::Zilla::Plugin::Test::NewVersion::VERSION = '0.001';
+  $Dist::Zilla::Plugin::Test::NewVersion::VERSION = '0.002';
 }
-# git description: be88591
+# git description: v0.001-4-g7867d20
 
 BEGIN {
   $Dist::Zilla::Plugin::Test::NewVersion::AUTHORITY = 'cpan:ETHER';
@@ -18,6 +18,7 @@ with
     'Dist::Zilla::Role::FileFinderUser' => {
         default_finders => [ ':InstallModules' ],
     },
+    'Dist::Zilla::Role::PrereqSource',
 ;
 use Sub::Exporter::ForMethods 'method_installer';
 use Data::Section 0.004 # fixed header_re
@@ -25,6 +26,21 @@ use Data::Section 0.004 # fixed header_re
     '-setup';
 use namespace::autoclean;
 
+sub register_prereqs
+{
+    my $self = shift;
+    $self->zilla->register_prereqs(
+        {
+            type  => 'requires',
+            phase => 'develop',
+        },
+        'Encode' => '0',
+        'LWP::UserAgent' => '0',
+        'JSON' => '0',
+        'Module::Runtime' => '0',
+    );
+}
+
 sub gather_files
 {
     my $self = shift;
@@ -63,7 +79,7 @@ sub gather_files
 
 =encoding utf-8
 
-=for :stopwords Karen Etheridge
+=for :stopwords Karen Etheridge FileFinder irc
 
 =head1 NAME
 
@@ -71,7 +87,54 @@ Dist::Zilla::Plugin::Test::NewVersion - Generate a test that checks a new versio
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head1 SYNOPSIS
+
+    # in dist.ini:
+    [Test::NewVersion]
+
+=head1 DESCRIPTION
+
+This L<Dist::Zilla> plugin generates a release test C<new-version.t>, which
+checks the PAUSE index for latest version of each module, to confirm that
+the version number(s) has been/have been incremented.
+
+This is mostly useful only for distributions that do not automatically
+increment their version from an external source, e.g.
+L<Dist::Zilla::Plugin::Git::NextVersion>.
+
+It is permitted for a module to have no version number at all, but if it is
+set, it must have been incremented from the previous value, as otherwise this case
+would be indistinguishable from developer error (forgetting to increment the
+version), which is what we're testing for.  You can, however, explicitly
+exclude some files from being checked, by passing your own
+L<FileFinder|Dist::Zilla::Role::FileFinderUser/default_finders>.
+
+=for Pod::Coverage register_prereqs gather_files
+
+=head1 CONFIGURATION
+
+This plugin takes as an optional setting:
+
+=over 4
+
+=item *
+
+C<finders> - list the finder(s), one per line, that are to be used for
+
+finding the modules to test.  Defaults to C<:InstallModules>; other
+pre-defined options are listed in L<FileFinder|Dist::Zilla::Role::FileFinderUser/default_finders>.
+You can define your own with the
+L<Dist::Zilla::Plugin::FileFinder::ByName|[FileFinder::ByName]> plugin.
+
+=back
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Test-NewVersion>
+(or L<bug-Dist-Zilla-Plugin-Test-NewVersion@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Test-NewVersion@rt.cpan.org>).
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
 =head1 AUTHOR
 
@@ -136,55 +199,3 @@ foreach my $pkg (
     note $message if $message;
 }
 __END__
-
-=pod
-
-=head1 SYNOPSIS
-
-    # in dist.ini:
-    [Test::NewVersion]
-
-=head1 DESCRIPTION
-
-=for stopwords FileFinder
-
-This L<Dist::Zilla> plugin generates a release test C<new-version.t>, which
-checks the PAUSE index for latest version of each module, to confirm that
-the version number(s) has been/have been incremented.
-
-This is mostly useful only for distributions that do not automatically
-increment their version from an external source, e.g.
-L<Dist::Zilla::Plugin::Git::NextVersion>.
-
-It is permitted for a module to have no version number at all, but if it is
-set, it have been incremented from the previous value, as otherwise this case
-would be indistinguishable from developer error (forgetting to increment the
-version), which is what we're testing for.  You can, however, explicitly
-exclude some files from being checked, by passing your own
-L<FileFinder|Dist::Zilla::Role::FileFinderUser/default_finders>.
-
-=for Pod::Coverage gather_files
-
-=head1 CONFIGURATION
-
-This plugin takes as an optional setting:
-
-=begin :list
-
-* C<finders> - list the finder(s), one per line, that are to be used for
-finding the modules to test.  Defaults to C<:InstallModules>; other
-pre-defined options are listed in L<FileFinder|Dist::Zilla::Role::FileFinderUser/default_finders>.
-You can define your own with the
-L<Dist::Zilla::Plugin::FileFinder::ByName|[FileFinder::ByName]> plugin.
-
-=end :list
-
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Test-NewVersion>
-(or L<bug-Dist-Zilla-Plugin-Test-NewVersion@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Test-NewVersion@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
-=cut
